package org.vendor.console;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.HashMap;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.text.DocumentEvent;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.WorkbenchEncoding;
import org.eclipse.ui.console.MessageConsole;
import org.eclipse.ui.console.MessageConsoleStream;

public class Console extends MessageConsole implements IDocumentListener {
  protected static final RGB RGB_DEFAULT = new RGB(0, 0, 0);
  
  protected static final RGB RGB_RECEIVED = new RGB(255, 0, 0);
  
  protected static final RGB RGB_WARNING = new RGB(255, 0, 255);
  
  protected static final RGB RGB_INFO = new RGB(0, 0, 255);
  
  protected static final String DEFAULT = "DEFAULT";
  
  protected static final String RECEIVED = "RECEIVED";
  
  protected static final String INFO = "INFO";
  
  protected static final String WARNING = "WARNING";
  
  private File backup = null;
  
  FileOutputStream out = null;
  
  protected HashMap<String, MessageConsoleStream> streams;
  
  public Console(String name, ImageDescriptor imageDescriptor) {
    super(name, imageDescriptor);
    this.streams = new HashMap<>();
    initConsole();
    setBackup(new File(getConsoleDirectory(), getBackupName()));
    try {
      this.out = new FileOutputStream(getBackup());
    } catch (FileNotFoundException e) {
      e.printStackTrace();
      System.err.println("Failed to create File for console " + name);
    } 
    setWaterMarks(400000, 500000);
    IDocument document = getDocument();
    document.addDocumentListener(this);
  }
  
  private String getBackupName() {
    return getName() + ".console";
  }
  
  private File getConsoleDirectory() {
    File file = new File("configuration");
    if (!file.exists() || !file.isDirectory()) {
      String path = Platform.getInstallLocation().getURL().toString();
      file = new File(path.substring(1) + "consoleLog");
    } else {
      file = new File("consoleLog");
    } 
    if (!file.exists() && !file.mkdirs())
      return null; 
    return file;
  }
  
  public Console(String name) {
    this(name, null);
  }
  
  public Console() {
    this("Console", null);
  }
  
  private void initConsole() {
    updateColor(getDefaultStream(), RGB_DEFAULT);
    updateColor(getReceivedStream(), RGB_RECEIVED);
    updateColor(getInfoStream(), RGB_INFO);
    updateColor(getWarningStream(), RGB_WARNING);
  }
  
  public MessageConsoleStream getDefaultStream() {
    MessageConsoleStream stream = this.streams.get("DEFAULT");
    if (stream == null) {
      stream = new MessageConsoleStream(this);
      this.streams.put("DEFAULT", stream);
      RGB rgb = RGB_DEFAULT;
      updateColor(stream, rgb);
    } 
    return stream;
  }
  
  public MessageConsoleStream getReceivedStream() {
    MessageConsoleStream stream = this.streams.get("RECEIVED");
    if (stream == null) {
      stream = new MessageConsoleStream(this);
      this.streams.put("RECEIVED", stream);
      RGB rgb = RGB_RECEIVED;
      updateColor(stream, rgb);
    } 
    return stream;
  }
  
  public MessageConsoleStream getWarningStream() {
    MessageConsoleStream stream = this.streams.get("WARNING");
    if (stream == null) {
      stream = new MessageConsoleStream(this);
      this.streams.put("WARNING", stream);
      RGB rgb = RGB_WARNING;
      updateColor(stream, rgb);
    } 
    return stream;
  }
  
  public MessageConsoleStream getInfoStream() {
    MessageConsoleStream stream = this.streams.get("INFO");
    if (stream == null || stream.isClosed()) {
      stream = new MessageConsoleStream(this);
      this.streams.put("INFO", stream);
      RGB rgb = RGB_INFO;
      updateColor(stream, rgb);
    } 
    return stream;
  }
  
  public static void updateColor(MessageConsoleStream stream, RGB color) {
    if (stream == null || color == null)
      return; 
    Color current = stream.getColor();
    if (current == null || !color.equals(current.getRGB()))
      Display.getDefault().asyncExec((Runnable)new Object(stream, color, current)); 
  }
  
  protected void dispose() {
    super.dispose();
    if (this.out != null)
      try {
        this.out.close();
      } catch (IOException e) {
        e.printStackTrace();
      }  
  }
  
  public boolean isClosed() {
    return (getDocument() == null);
  }
  
  public void documentAboutToBeChanged(DocumentEvent event) {}
  
  public void documentChanged(DocumentEvent event) {
    String txt = event.fText;
    if (this.out != null)
      try {
        this.out.write(txt.getBytes(WorkbenchEncoding.getWorkbenchDefaultEncoding()));
      } catch (IOException e) {
        e.printStackTrace();
      }  
  }
  
  public final File getBackup() {
    return this.backup;
  }
  
  private final void setBackup(File backup) {
    this.backup = backup;
  }
}
